# -*- encoding: utf-8 -*-
"""
    flask_triangle.widgets.uibootstrap
    ----------------------------------

    Widgets for the UI-Bootstrap project.

    :copyright: (c) 2013 by Morgan Delahaye-Prat.
    :license: BSD, see LICENSE for more details.
"""


from __future__ import absolute_import
from __future__ import unicode_literals

from .typeahead import Typeahead
from .datepicker import Datepicker

__all__ = ['Typeahead', 'Datepicker']
